@@ -131,7 +131,7 @@ inline auto simplify_object(const simdjson::dom::object object,
     for (auto&& [key, value] : object) {
         out[i] = simplify_element<type_policy, int64_opt, simplify_to>(
             value, empty_array, empty_object, single_null);
-        out_names[i++] = std::string(key);
+        out_names[i++] = Rcpp::String(std::string(key));
     }
 
     out.attr("names") = out_names;
@@ -188,7 +188,7 @@ inline auto simplify_element(simdjson::dom::element element,
             return Rcpp::wrap(element.get<bool>().first);
 
         case simdjson::dom::element_type::STRING:
-            return Rcpp::wrap(element.get<const char*>().first);
+            return Rcpp::wrap(Rcpp::String(std::string(element.get<std::string_view>().first)));
 
         case simdjson::dom::element_type::NULL_VALUE:
             return single_null;
